# Quintet

QUINTET - QUick sIgNal To noisE raTio

is a fast package for computing signal-to-noise ratios for any spinless, non-HOM binary black hole system.

# Installation

* git clone https://git.ligo.org/otto.hannuksela/quintet.git
* cd quintet .
* from datetime import datetime

# How to use (python ide)

* from quintet import Quintet as quin
* quin_ = quin()

## for further details on how to use, refer to quintet/test.ipynb file
